@@ -120,7 +120,7 @@ def _get_create_hashname():
         with open(out_path, "r") as out_file:
             out = json.load(out_file)
             if "hashname" in out:
-                return out["hashname"]
+                return out["hashname"].replace(" ", "_")
 
         # If not then make one
         with open(cwd / "idk.json", "r") as config:
@@ -139,7 +139,7 @@ def _get_create_hashname():
         with open(out_path, "w+") as out_file:
             out_file.write(json.dumps(out, indent=4))
 
-    return out["hashname"]
+    return out["hashname"].replace(" ", "_")
 
 
 def _gzip_dir(cwd):
@@ -177,4 +177,4 @@ def _get_base_prefix_compat():
 
 
 def _in_virtualenv():
-    return "VIRTUAL_ENV" in os.environ or _get_base_prefix_compat() != sys.prefix
\ No newline at end of file
+    return "VIRTUAL_ENV" in os.environ or _get_base_prefix_compat() != sys.prefix
